@@ -33,9 +33,16 @@ private slots:
 
     void on_pushButtonDefault_clicked();
 
-
     void on_checkBoxGeneralSetting_clicked();
 
+    void on_pushButtonMinusTen_clicked();
+
+    void on_pushButtonMinusOne_clicked();
+
+    void on_pushButtonPlusOne_clicked();
+
+    void on_pushButtonPlusTen_clicked();
+
 private:
     Ui::Settings *ui;
 };
