@@ -27,11 +27,13 @@ private slots:
 
     void on_pushButtonTstop_clicked();
 
-    void on_pushButton30_clicked();
+    void on_radioButton30_clicked();
 
-    void on_pushButton60_clicked();
+    void on_radioButton60_clicked();
 
-    void on_pushButton120_clicked();
+    void on_radioButton120_clicked();
+
+    void on_pushButtonTap_clicked();
 
     //Timers
     void on_timer();
@@ -43,6 +45,7 @@ private slots:
     void on_t60Timeout();
     void on_t120Timeout();
 
+
 private:
     Ui::Training *ui;
     QProcess *t_process;
